@@ -51,6 +51,7 @@ tsb <- function(data,h=10,w=NULL,init=c("mean","naive"),
   init.opt <- init.opt[1]
   outplot <- outplot[1]
   opt.on <- opt.on[1]
+  na.rm <- na.rm[1]
   if (!is.numeric(init)){
     init <- init[1]
   } else {
@@ -63,6 +64,9 @@ tsb <- function(data,h=10,w=NULL,init=c("mean","naive"),
   
   # Prepare data
   if (class(data)=="data.frame"){
+    if (ncol(data)>1){
+      warning("Data frame with more than one columns. Using only first one.")
+    }
     data <- data[[1]]
   }
   if (na.rm == TRUE){
